==> webgui_7.9.33.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_Carousel.pm <==
package WebGUI::i18n::Spanish::Asset_Carousel;
use utf8;
our $I18N = {
  'assetName' => {
    'lastUpdated' => '1252512946',
    'message' => 'Carrusel'
  },
  'carousel autoPlay description' => {
    'lastUpdated' => '1302868491',
    'message' => 'Indica si este Carrusel iniciará de manera automática la secuencia de presentación de los items que contiene.'
  },
  'carousel autoPlay label' => {
    'lastUpdated' => '1302868500',
    'message' => 'Reproducción Automática'
  },
  'carousel autoPlayInterval description' => {
    'lastUpdated' => '1302868531',
    'message' => 'Intervalo de tiempo entre el despliegue de dos elementos del Carrusel.'
  },
  'carousel autoPlayInterval label' => {
    'lastUpdated' => '1302868554',
    'message' => 'Intervalo entre Items'
  },
  'carousel slideHeight description' => {
    'lastUpdated' => '1280335493',
    'message' => 'Altura en pixels. El Carrusel no cambia sus dimensiones cuando el contenido a mostrar tiene alturas variables. Establecer este parámetro facilita la presentación adecuada. El valor por omisión es cero, que establece la altura del Carrusel con el mismo valor que la altura del primer elemento a mostrar.'
  },
  'carousel slideHeight label' => {
    'lastUpdated' => '1280335521',
    'message' => 'Altura de Diapositiva en Carrusel'
  },
  'carousel slideWidth description' => {
    'lastUpdated' => '1252513017',
    'message' => 'Anchura en pixels. El Carrusel no se redimensiona automáticamente si el contenido tiene anchura variable. Especificar esta anchura ayuda a que la presentación del Carrusel sea apropiada. Si se deja en 0, entonces la anchura del Carrusel será determinada por la anchura del primer elemento.'
  },
  'carousel slideWidth label' => {
    'lastUpdated' => '1252513036',
    'message' => 'Anchura de una Lámina'
  },
  'carousel template description' => {
    'lastUpdated' => '1252513051',
    'message' => 'Seleccione la Plantilla para desplegar este Carrusel.'
  },
  'carousel template help title' => {
    'lastUpdated' => '1252513065',
    'message' => 'Carrusel, Variables de Plantilla'
  },
  'carousel template label' => {
    'lastUpdated' => '1252513157',
    'message' => 'Plantilla para el Carrusel'
  },
  'delete' => {
    'lastUpdated' => '1302868562',
    'message' => 'Eliminar'
  },
  'id description' => {
    'lastUpdated' => '1252513181',
    'message' => 'Indique el ID único para este ítem en el Carrusel.'
  },
  'id label' => {
    'lastUpdated' => '1252513189',
    'message' => 'ID'
  },
  'itemId' => {
    'lastUpdated' => '1252513206',
    'message' => 'El ID de este tiem en el Carrusel.'
  },
  'item_loop' => {
    'lastUpdated' => '1252513219',
    'message' => 'Un ciclo que contiene todos los items del Carrusel.'
  },
  'items description' => {
    'lastUpdated' => '1252513236',
    'message' => 'Introduzca los items de este Carrusel.'
  },
  'items label' => {
    'lastUpdated' => '1252513284',
    'message' => 'Items'
  },
  'sequenceNumber' => {
    'lastUpdated' => '1252513303',
    'message' => 'El <strong>sequenceNumber</strong> para este item del Carrusel'
  },
  'slideHeight' => {
    'lastUpdated' => '1280335538',
    'message' => 'La altura de diapositiva establecida para el Carrusel.'
  },
  'slideWidth' => {
    'lastUpdated' => '1252513318',
    'message' => 'La anchura establecida para las láminas del Carrusel.'
  },
  'text' => {
    'lastUpdated' => '1252513347',
    'message' => 'El texto de este item del Carrusel.'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_Carousel.pm <==
package WebGUI::i18n::Spanish::Asset_Carousel;
use utf8;
our $I18N = {
  'assetName' => {
    'lastUpdated' => '1252512946',
    'message' => 'Carrusel'
  },
  'carousel autoPlay description' => {
    'lastUpdated' => '1302868491',
    'message' => 'Indica si este Carrusel iniciará de manera automática la secuencia de presentación de los items que contiene.'
  },
  'carousel autoPlay label' => {
    'lastUpdated' => '1302868500',
    'message' => 'Reproducción Automática'
  },
  'carousel autoPlayInterval description' => {
    'lastUpdated' => '1302868531',
    'message' => 'Intervalo de tiempo entre el despliegue de dos elementos del Carrusel.'
  },
  'carousel autoPlayInterval label' => {
    'lastUpdated' => '1302868554',
    'message' => 'Intervalo entre Items'
  },
  'carousel slideHeight description' => {
    'lastUpdated' => '1280335493',
    'message' => 'Altura en pixels. El Carrusel no cambia sus dimensiones cuando el contenido a mostrar tiene alturas variables. Establecer este parámetro facilita la presentación adecuada. El valor por omisión es cero, que establece la altura del Carrusel con el mismo valor que la altura del primer elemento a mostrar.'
  },
  'carousel slideHeight label' => {
    'lastUpdated' => '1280335521',
    'message' => 'Altura de Diapositiva en Carrusel'
  },
  'carousel slideWidth description' => {
    'lastUpdated' => '1252513017',
    'message' => 'Anchura en pixels. El Carrusel no se redimensiona automáticamente si el contenido tiene anchura variable. Especificar esta anchura ayuda a que la presentación del Carrusel sea apropiada. Si se deja en 0, entonces la anchura del Carrusel será determinada por la anchura del primer elemento.'
  },
  'carousel slideWidth label' => {
    'lastUpdated' => '1252513036',
    'message' => 'Anchura de una Lámina'
  },
  'carousel template description' => {
    'lastUpdated' => '1252513051',
    'message' => 'Seleccione la Plantilla para desplegar este Carrusel.'
  },
  'carousel template help title' => {
    'lastUpdated' => '1252513065',
    'message' => 'Carrusel, Variables de Plantilla'
  },
  'carousel template label' => {
    'lastUpdated' => '1252513157',
    'message' => 'Plantilla para el Carrusel'
  },
  'delete' => {
    'lastUpdated' => '1302868562',
    'message' => 'Eliminar'
  },
  'id description' => {
    'lastUpdated' => '1252513181',
    'message' => 'Indique el ID único para este ítem en el Carrusel.'
  },
  'id label' => {
    'lastUpdated' => '1252513189',
    'message' => 'ID'
  },
  'itemId' => {
    'lastUpdated' => '1252513206',
    'message' => 'El ID de este tiem en el Carrusel.'
  },
  'item_loop' => {
    'lastUpdated' => '1252513219',
    'message' => 'Un ciclo que contiene todos los items del Carrusel.'
  },
  'items description' => {
    'lastUpdated' => '1252513236',
    'message' => 'Introduzca los items de este Carrusel.'
  },
  'items label' => {
    'lastUpdated' => '1252513284',
    'message' => 'Items'
  },
  'rich editor description' => {
    'lastUpdated' => '1307399224',
    'message' => 'Seleccione el editor empleado para ingresar contenido en el Carrusel. El cambio será efectivo la próxima vez que se edite el Carrusel.'
  },
  'sequenceNumber' => {
    'lastUpdated' => '1252513303',
    'message' => 'El <strong>sequenceNumber</strong> para este item del Carrusel'
  },
  'slideHeight' => {
    'lastUpdated' => '1280335538',
    'message' => 'La altura de diapositiva establecida para el Carrusel.'
  },
  'slideWidth' => {
    'lastUpdated' => '1252513318',
    'message' => 'La anchura establecida para las láminas del Carrusel.'
  },
  'text' => {
    'lastUpdated' => '1252513347',
    'message' => 'El texto de este item del Carrusel.'
  }
}
;

1;
